@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 import os
+#import proj as p
 try:
   import time
   import sys
@@ -13,12 +14,158 @@ try:
   import shutil
 
   from tqdm import tqdm
+  
 
 except:
   print("Installing dependencies of build...")
   os.system("pip install tqdm")
 
 
+import json
+import os
+
+
+pos = ["name","run","version","dependencies","modules","projects","authors"]
+class main:
+  def openproj():
+    with open(f"{os.getcwd()}/build.proj") as w:
+      content = w.read()
+      if content == "":
+        with open(f"{os.getcwd()}/build.proj","w") as x:
+          x.write("{}")
+
+    with open(f"{os.getcwd()}/build.proj") as w:
+      content = w.read()
+
+      
+        
+      x = json.loads(content)
+    return x
+
+  def writeproj(proj):
+    x = {}
+
+    x = json.dumps(proj,indent=4)
+
+
+    with open(f"{os.getcwd()}/build.proj","w") as w:
+      w.write(x)
+
+
+
+  def structproj(): # just a ref
+    
+    proj = main.openproj()
+
+    # main struct
+
+    name = proj["name"]
+    author = proj["authors"]
+    ver = proj["version"]
+    run = proj["run"]
+    deps = proj["dependencies"]
+    mods = proj["modules"]
+
+
+
+    # projects struct
+    x = "example" # insert project name
+    path = proj["projects"][x] # path to .project file
+
+
+    
+
+  def parseproj(opt,arg,args): # just a ref
+    
+    proj = main.openproj()
+
+    # main struct
+    try:
+
+      name = proj["name"]
+      authors = proj["authors"]
+      ver = proj["version"]
+      run = proj["run"]
+      deps = proj["dependencies"]
+      mods = proj["modules"]
+      projects = []
+      for item in proj["projects"]:
+        projects.append(item)
+    except KeyError:
+      if arg != "init":
+        return print("ERROR: values not found")
+
+
+
+    if opt == "--proj":
+      if arg == "info":
+        print(f"NAME: {name}\nAUTHORS: {authors}\nVERSION: {ver}")
+      if arg == "init":
+        os.system(f"touch {os.getcwd()}/build.proj")
+        proj = main.openproj()
+        proj["name"] = "Name"
+        proj["authors"] = []
+        proj["version"] = "0.0.1"
+        proj["run"] = "echo You can use Installfile by replacing this string with 'Installfile' "
+        proj["dependencies"] = ["echo You can use Buildfile by replacing this string with 'Buildfile' ","echo eg. pip install <package>"]
+        proj["modules"] = ["https://pathtozipwithlocalmodules.com/module.zip"]
+        proj["projects"] = []
+        print(proj)
+        main.writeproj(proj)
+      if arg == "set" or arg == "add":
+        msg = ""
+        val = args[0]
+        toset = ""
+        for item in args:
+          if item != args[0]:
+            if item == args[len(args)-1]:
+              toset += f"{item}"
+            else:
+              toset += f"{item} "
+
+        posx = pos
+        posx.remove("projects")
+
+
+
+        if val not in posx:
+          return print("Value does not exist in build.proj")
+        proj = main.openproj()
+        if val in ["dependencies","modules","authors","projects"]:
+          if toset in proj[val]:
+            proj[val].remove(toset)
+            msg = "removed"
+          else:
+            proj[val].append(toset)
+            msg = "added"
+          
+        else:
+          proj[val] = toset
+          msg = "set"
+        main.writeproj(proj)
+        print(f"Successfully {msg} '{val}' as '{toset}'")
+      if arg == "run":
+        proj = main.openproj()
+        run = proj["run"]
+        if run == "Installfile":
+          build.default({"x":"t","file":"Installfile","args":args})
+        else:
+          os.system(run)
+      if arg == "dependencies" or arg == "deps":
+        proj = main.openproj()
+        run = proj["dependencies"]
+        if deps[0] == "Buildfile":
+          build.default({"x":"t","args":args})
+        else:
+          for item in deps:
+            os.system(item)
+
+
+
+
+
+
+
 vars = {}
 
 
@@ -101,7 +248,12 @@ def send_help():
     print('USAGE: build [options]')
     print('A build tool created by Ehnryu\n')
     print('Basic options:\n')
-    print('--compress : compress an archive\n')
+    print('--help : this command\n')
+    print('--build : build a project\n')
+    print('--install : install a project\n')
+    print('--sendargs : send arguments to a project\n')
+    print('--runfunc : run a specialized function\n')
+    print('--proj : configure a project\n')
 
 def printc(color,*text):
   CEND      = '\33[0m'
@@ -113,7 +265,7 @@ def run(command):
     subprocess.check_output(command,shell=True)
 
 def main():
-    advanced = ["sendargs =","runfunc =","build"]
+    advanced = ["help","sendargs =","runfunc =","build","install","proj ="]
 
 
     argv = sys.argv[1:]
@@ -131,13 +283,20 @@ def main():
     for opt, arg in opts:
         opt = opt.rstrip()
         opt = opt.replace(" ","")
+        opt = opt.lower()
 
         if opt in ["-h","--help"]:
           send_help()
+
+        if opt in ["--proj"]:
+          main.parseproj(opt,arg,args)
+          
         if opt in ["--sendargs"]:
           return {"x":"t","args":sys.argv}
         if opt in ["--build"]:
           return {"x":"t","args":args}
+        if opt in ["--install"]:
+          return {"x":"t","file":"Installfile","args":args}
         if opt in ["--runfunc","-r"]:
           return {"x":"t","args":args,"func":arg}
 
@@ -146,13 +305,20 @@ def main():
 
 
 
-x = main()
+
 
 def default(x):
   if x != None:
     if x["x"] == "t":
+      file = f"{os.getcwd}/Buildfile"
+      try:
+        file = x["file"]
+      except KeyError:
+        file = f"{os.getcwd}/Buildfile"
+
       args = x["args"]
       argz = ""
+
       for item in args:
         if item not in ["build","build.py","main.py","--sendargs"]:
           if item != args[len(args)-1]:
@@ -160,15 +326,15 @@ def default(x):
           else:
             argz += f"{item}"
       files = []
-      for file in os.listdir(os.getcwd()):
-        files.append(file)
-      if "Buildfile" in files:
+      for filex in os.listdir(os.getcwd()):
+        files.append(filex)
+      if file in files:
         xylo = False
         tex = ""
         line = 0
         function = ""
         printc(CVIOLET,"Running build ...")
-        f = open("Buildfile", "r")
+        f = open(f"{os.getcwd()}/{file}", "r")
         try:
           func = x["func"]
         except KeyError:
@@ -462,7 +628,8 @@ def default(x):
       elif "Makefile" in files:
         printc(CVIOLET,"Running make ...")
         run("make")
-default(x)
+
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    x = main()
+    default(x)
\ No newline at end of file
